@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.03_02';
+$VERSION = '2.03_03';
 
 bootstrap DBD::mSQL $VERSION;
 
@@ -570,11 +570,8 @@ handles (read only):
 
     $infoString = $dbh->{'info'};
     $threadId = $dbh->{'thread_id'};
-    $insertId = $dbh->{'insertid'};
 
-These correspond to mysql_info(), mysql_thread_id() and mysql_insert_id(),
-respectively. Note that the latter depends on the query and becomes invalid
-when executing another query. You might prefer $sth->{'insertid'}.
+These correspond to mysql_info() and mysql_tread_id(), respectively.
 
 
 =head1 STATEMENT HANDLES
@@ -647,9 +644,6 @@ MySQL has the ability to choose unique key values automatically. If this
 happened, the new ID will be stored in this attribute. This attribute
 is not valid for DBD::mSQL.
 
-Note that you may also use $dbh->{'insertid'}, as long as you don't
-use other statement handles.
-
 =item is_blob
 
 Reference to an array of boolean values; TRUE indicates, that the
